@@ -1,10 +1,11 @@
 package Net::RabbitMQ::Simple;
-our $VERSION = "0.0006";
+our $VERSION = "0.0007";
 
 use Moose;
 use 5.008001;
 use Devel::Declare ();
 use Carp qw/ confess /;
+use namespace::autoclean;
 
 extends 'Devel::Declare::Context::Simple';
 
@@ -135,11 +136,37 @@ sub exchange_delete (@) {
 
     $_mq->exchange_delete($exchange, %{$opt});
 }
+
+=head2 queue %hash
+
+Declare new queue.
+
+    queue {
+        name => 'foobaz',
+        passive => 0,
+        durable => 0,
+        exclusive => 0,
+        auto_delete => 1
+    };
+
+=cut
+
+sub queue (@) {
+    my ($opt) = @_;
+
+    my $queue = $opt->{name};
+    Carp::confess("please give the queue name") if !$queue;
+    delete $opt->{name};
+    
+    $_mq->queue_declare($queue, %{$opt});    
+}
+
 =head2 exchange_publish %hash
 
 Publish a new message.
 
     {
+        channel => 1, # optional
         exchange => 'exchange',
         queue => 'queue',
         route => 'route',
@@ -153,7 +180,6 @@ sub publish (@) {
     my ($opt) = @_;
    
     $_mq->exchange_name($opt->{exchange}) if $opt->{exchange};
-
     $_mq->queue_declare($opt->{queue}, %{$opt->{queue_options}});
     $_mq->queue_bind($opt->{route});
 
@@ -270,7 +296,7 @@ sub import {
 
     my @cmds = ( 'mqconnect', 'publish', 'consume', 'purge', 'ack',
         'mqdisconnect', 'exchange', 'get', 'exchange_delete',
-        'tx', 'commit', 'rollback');
+        'tx', 'commit', 'rollback', 'queue');
 
     Devel::Declare->setup_for(
         $caller, {
